@@ -1,8 +1,7 @@
-import log
 import logging
 
-from fileFormatter import FileFormatter
-from cmdParser import CmdParser
+from .fileFormatter import FileFormatter
+from .cmdParser import CmdParser
 
 logger = logging.getLogger('Formatter')
 
